==> haskell-regex-compat-tdfa-0.95.1.4-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-2gLzbQ9jLcw5gvM26Qcuji
key: regex-compat-tdfa-0.95.1.4-2gLzbQ9jLcw5gvM26Qcuji
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Text.Regex
abi: 7fdad1c2ca424cb7d54e206dfa871320
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-2gLzbQ9jLcw5gvM26Qcuji
depends:
    array-0.5.2.0 base-4.10.1.0 regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
    regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=d7d8f12e28b86f8254a2a5665d808c04
             regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8=e1619b316a6b2dcb983f330c43208f5f
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-41IMIgw1pSd3zjF8D8O8zC
key: regex-compat-tdfa-0.95.1.4-41IMIgw1pSd3zjF8D8O8zC
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Text.Regex
abi: ee57612f7dc6dbaa849592b56f595297
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-41IMIgw1pSd3zjF8D8O8zC
depends:
    array-0.5.2.0 base-4.10.1.0 regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
    regex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=d7d8f12e28b86f8254a2a5665d808c04
             regex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2=1f7384d261dd3860221965b2d2274d30
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
